@@ -26,6 +26,8 @@ if not session.authorized:
 else:
     response.menu.append((T('Logout'), False,
                           URL(_a,'default',f='logout')))
+    response.menu.append((T('Debug'), False, 
+                          URL(_a, 'debug','interact')))
 
 if os.path.exists('applications/examples'):
     response.menu.append((T('Help'), False, URL('examples','default','index')))
