@@ -7,39 +7,45 @@ response.keywords = T('web2py, Python, Web Framework')
 response.description = T('web2py Web Framework')
 
 session.forget()
+cache_expire = not request.is_local and 300 or 0
 
-@cache('index')
+@cache('index', time_expire=cache_expire)
 def index():
     return response.render()
 
-@cache('what')
+@cache('what', time_expire=cache_expire)
 def what():
-    return response.render()
+    import urllib;
+    try:
+        images = XML(urllib.urlopen('http://web2py.com/poweredby/default/images').read())
+    except:
+        images = []
+    return response.render(images=images)
 
-@cache('download')
+@cache('download', time_expire=cache_expire)
 def download():
     return response.render()
 
-@cache('who')
+@cache('who', time_expire=cache_expire)
 def who():
     return response.render()
 
-@cache('support')
+@cache('support', time_expire=cache_expire)
 def support():
     return response.render()
 
-@cache('documentation')
+@cache('documentation', time_expire=cache_expire)
 def documentation():
     return response.render()
 
-@cache('usergroups')
+@cache('usergroups', time_expire=cache_expire)
 def usergroups():
     return response.render()
 
 def contact():
     redirect(URL('default','usergroups'))
 
-@cache('videos')
+@cache('videos', time_expire=cache_expire)
 def videos():
     return response.render()
 
@@ -49,7 +55,7 @@ def security():
 def api():
     redirect('http://web2py.com/book/default/chapter/04#API')
 
-@cache('license')
+@cache('license', time_expire=cache_expire)
 def license():
     import os
     filename = os.path.join(request.env.gluon_parent, 'LICENSE')
@@ -58,12 +64,13 @@ def license():
 def version():
     return 'Version %s.%s.%s (%s) %s' % request.env.web2py_version
 
-@cache('examples')
+@cache('examples', time_expire=cache_expire)
 def examples():
     return response.render()
 
-@cache('changelog')
+@cache('changelog', time_expire=cache_expire)
 def changelog():
     import os
-    filename = os.path.join(request.env.gluon_parent, 'README')
+    filename = os.path.join(request.env.gluon_parent, 'CHANGELOG')
     return response.render(dict(changelog=MARKMIN(read_file(filename))))
+
