@@ -16,7 +16,7 @@ def form():
            value='write something here')),
         TR('', INPUT(_type='submit', _value='SUBMIT')),
         ))
-    if form.accepts(request.vars, session):
+    if form.process().accepted:
         response.flash = 'form accepted'
     elif form.errors:
         response.flash = 'form is invalid'
@@ -25,3 +25,4 @@ def form():
     return dict(form=form, vars=form.vars)
 
 
+
