@@ -1098,7 +1098,7 @@ class FPDF:
                 self._out('/Filter /'+info['f'])
             if 'parms' in info:
                 self._out(info['parms'])
-            if('trns' in info and type([])==info['trns']):
+            if('trns' in info and isinstance(info['trns'],list)):
                 trns=''
                 for i in xrange(0,len(info['trns'])):
                     trns+=str(info['trns'][i])+' '+str(info['trns'][i])+' '
@@ -1684,3 +1684,4 @@ fpdf_charwidths['zapfdingbats']={
     '\xf2':760,'\xf3':946,'\xf4':771,'\xf5':865,'\xf6':771,'\xf7':888,'\xf8':967,'\xf9':888,'\xfa':831,'\xfb':873,'\xfc':927,'\xfd':970,'\xfe':918,'\xff':0}
 
 
+
