@@ -9,13 +9,13 @@ import threading
 
 # Install the new import function:
 def custom_import_install(web2py_path):
-        global _web2py_importer
-        global _web2py_path
-        if _web2py_importer:
-            return  # Already installed
-        _web2py_path = web2py_path
-        _web2py_importer = _Web2pyImporter(web2py_path)
-        __builtin__.__import__ = _web2py_importer
+    global _web2py_importer
+    global _web2py_path
+    if isinstance(__builtin__.__import__, _Web2pyImporter):
+        return #aready installed
+    _web2py_path = web2py_path
+    _web2py_importer = _Web2pyImporter(web2py_path)
+    __builtin__.__import__ = _web2py_importer
 
 def is_tracking_changes():
     """
@@ -41,7 +41,7 @@ def track_changes(track=True):
     if track:
         if not _web2py_date_tracker_importer:
             _web2py_date_tracker_importer = \
-              _Web2pyDateTrackerImporter(_web2py_path)
+                _Web2pyDateTrackerImporter(_web2py_path)
         __builtin__.__import__ = _web2py_date_tracker_importer
     else:
         __builtin__.__import__ = _web2py_importer
@@ -67,14 +67,14 @@ class _BaseImporter(object):
         """
 
     def __call__(self, name, globals=None, locals=None,
-		 fromlist=None, level=-1):
+                 fromlist=None, level=-1):
         """
         The import method itself.
         """
         return _STANDARD_PYTHON_IMPORTER(name,
-					 globals,
-					 locals,
-					 fromlist,
+                                         globals,
+                                         locals,
+                                         fromlist,
                                          level)
 
     def end(self):
@@ -102,20 +102,19 @@ class _DateTrackerImporter(_BaseImporter):
         self._tl._modules_loaded = set()
 
     def __call__(self, name, globals=None, locals=None,
-		 fromlist=None, level=-1):
+                 fromlist=None, level=-1):
         """
         The import method itself.
         """
 
-	globals = globals or {}
-	locals = locals or {}
-	fromlist = fromlist or []
+        globals = globals or {}
+        locals = locals or {}
+        fromlist = fromlist or []
 
         call_begin_end = self._tl._modules_loaded is None
         if call_begin_end:
             self.begin()
-
-	try:
+        try:
             self._tl.globals = globals
             self._tl.locals = locals
             self._tl.level = level
@@ -252,14 +251,14 @@ class _Web2pyImporter(_BaseImporter):
         return False
 
     def __call__(self, name, globals=None, locals=None,
-		 fromlist=None, level=-1):
+                 fromlist=None, level=-1):
         """
         The import method itself.
         """
 
-	globals = globals or {}
-	locals = locals or {}
-	fromlist = fromlist or []
+        globals = globals or {}
+        locals = locals or {}
+        fromlist = fromlist or []
 
         self.begin()
         #try:
@@ -325,3 +324,6 @@ class _Web2pyDateTrackerImporter(_Web2pyImporter, _DateTrackerImporter):
 
 
 
+
+
+
