@@ -37,23 +37,24 @@ def custom_json(o):
         raise TypeError(repr(o) + " is not JSON serializable")
 
 
-def xml_rec(value, key):
+def xml_rec(value, key, quote=True):
     if hasattr(value,'custom_xml') and callable(value.custom_xml):
         return value.custom_xml()
     elif isinstance(value, (dict, Storage)):
-        return TAG[key](*[TAG[k](xml_rec(v, '')) for k, v in value.items()])
+        return TAG[key](*[TAG[k](xml_rec(v, '',quote)) \
+                              for k, v in value.items()])
     elif isinstance(value, list):
-        return TAG[key](*[TAG.item(xml_rec(item, '')) for item in value])
+        return TAG[key](*[TAG.item(xml_rec(item, '',quote)) for item in value])
     elif hasattr(value,'as_list') and callable(value.as_list):
-        return str(xml_rec(value.as_list(),''))
+        return str(xml_rec(value.as_list(),'',quote))
     elif hasattr(value,'as_dict') and callable(value.as_dict):
-        return str(xml_rec(value.as_dict(),''))
+        return str(xml_rec(value.as_dict(),'',quote))
     else:
-        return xmlescape(value)
+        return xmlescape(value,quote)
 
 
-def xml(value, encoding='UTF-8', key='document'):
-    return ('<?xml version="1.0" encoding="%s"?>' % encoding) + str(xml_rec(value,key))
+def xml(value, encoding='UTF-8', key='document', quote=True):
+    return ('<?xml version="1.0" encoding="%s"?>' % encoding) + str(xml_rec(value,key,quote))
 
 
 def json(value,default=custom_json):
@@ -85,3 +86,4 @@ def rss(feed):
 
 
 
+
