@@ -770,6 +770,12 @@ class TestRouter(unittest.TestCase):
             "/init/default/f ['', 'arg1']")
         self.assertEqual(filter_url('http://domain.com/init/default/f/arg1/arg2'), 
             "/init/default/f ['arg1', 'arg2']")
+        self.assertEqual(filter_url('http://domain.com/init/default/f/arg1//arg2'), 
+            "/init/default/f ['arg1', '', 'arg2']")
+        self.assertEqual(filter_url('http://domain.com/init/default/f/arg1//arg3/'), 
+            "/init/default/f ['arg1', '', 'arg3']")
+        self.assertEqual(filter_url('http://domain.com/init/default/f/arg1//arg3//'), 
+            "/init/default/f ['arg1', '', 'arg3', '']")
 
         self.assertEqual(filter_url('http://domain.com/init/default/f', out=True), "/f")
         self.assertEqual(map_url_out(None, None, 'init', 'default', 'f', None, None, None, None, None), "/f")
@@ -845,7 +851,7 @@ class TestRouter(unittest.TestCase):
         r = Storage()
         r.env = Storage()
         r.env.http_host = 'domain.com'
-        r.env.WSGI_URL_SCHEME = 'httpx' # distinguish incoming scheme
+        r.env.wsgi_url_scheme = 'httpx' # distinguish incoming scheme
         self.assertEqual(str(URL(r=r, a='a', c='c', f='f')), "/a/c/f")
         self.assertEqual(str(URL(r=r, a='a', c='c', f='f', host=True)), 
             "httpx://domain.com/a/c/f")
