@@ -237,6 +237,12 @@ routes_out = [
             "/welcome/default/f ['', 'arg1']")
         self.assertEqual(filter_url('http://domain.com/welcome/default/f/arg1/arg2'), 
             "/welcome/default/f ['arg1', 'arg2']")
+        self.assertEqual(filter_url('http://domain.com/welcome/default/f/arg1//arg2'), 
+            "/welcome/default/f ['arg1', '', 'arg2']")
+        self.assertEqual(filter_url('http://domain.com/welcome/default/f/arg1//arg3/'), 
+            "/welcome/default/f ['arg1', '', 'arg3']")
+        self.assertEqual(filter_url('http://domain.com/welcome/default/f/arg1//arg3//'), 
+            "/welcome/default/f ['arg1', '', 'arg3', '']")
 
         self.assertEqual(filter_url('http://domain.com/welcome/default/f', out=True), "/f")
         self.assertEqual(regex_filter_out('/welcome/default/f'), "/f")
@@ -304,7 +310,7 @@ routes_out = [
         r = Storage()
         r.env = Storage()
         r.env.http_host = 'domain.com'
-        r.env.WSGI_URL_SCHEME = 'httpx' # distinguish incoming scheme
+        r.env.wsgi_url_scheme = 'httpx' # distinguish incoming scheme
         self.assertEqual(str(URL(r=r, a='a', c='c', f='f')), "/a/c/f")
         self.assertEqual(str(URL(r=r, a='a', c='c', f='f', host=True)), 
             "httpx://domain.com/a/c/f")
