@@ -103,6 +103,12 @@ routers = dict(
     ),
 )
 
+# Specify log level for rewrite's debug logging
+# Possible values: debug, info, warning, error, critical (loglevels),
+#                  off, print (print uses print statement rather than logging)
+# GAE users may want to use 'off' to suppress routine logging.
+#
+logging = 'debug'
 
 # Error-handling redirects all HTTP errors (status codes >= 400) to a specified
 # path.  If you wish to use error-handling redirects, uncomment the tuple
@@ -200,3 +206,4 @@ if __name__ == '__main__':
     import doctest
     doctest.testmod()
 
+
