@@ -615,8 +615,8 @@ informix://username:password@test\n\
         oCopy.sourcedbType=sourceItems[0]
         oCopy.sourcedbName=sourceItems[1]
         targetItems=string.split(args.targetConnectionString,'://')    
-        oCopy.targetdbType=sourceItems[0]
-        oCopy.targetdbName=sourceItems[1]
+        oCopy.targetdbType=targetItems[0]
+        oCopy.targetdbName=targetItems[1]
     except Exception, err:
         print('EXCEPTION: {0}'.format(err))
 
@@ -679,4 +679,4 @@ target model: {1}\n\
             print('EXCEPTION: could not make a copy of the database\n{0}'.format(err)) 
     else:
         s=dalShell()
-        s.shell(db)
\ No newline at end of file
+        s.shell(db)
